@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: AdvancedSearchPane.java 986 2006-01-23 19:22:50Z dmsmith $
+ * ID: $Id: AdvancedSearchPane.java 1170 2006-10-19 21:49:36Z dmsmith $
  */
 package org.crosswire.bibledesktop.book;
 
@@ -321,7 +321,7 @@ public class AdvancedSearchPane extends JPanel implements DocumentListener
         return chkRank.isSelected();
     }
 
-    public void setLabelRank(int val)
+    public final void setLabelRank(int val)
     {
         if (val == 0)
         {
@@ -458,7 +458,7 @@ public class AdvancedSearchPane extends JPanel implements DocumentListener
     /**
      *
      */
-    public void updatePreset()
+    public final void updatePreset()
     {
         if (editingRestrict)
         {
