@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: XSLTProperty.java 1095 2006-07-23 19:15:47Z dmsmith $
+ * ID: $Id: XSLTProperty.java 1170 2006-10-19 21:49:36Z dmsmith $
  */
 package org.crosswire.bibledesktop.desktop;
 
@@ -76,6 +76,11 @@ public final class XSLTProperty implements Serializable
      */
     public static final XSLTProperty TINY_VERSE_NUMBERS = new XSLTProperty("TinyVNum", true); //$NON-NLS-1$
 
+    /**
+     * Should headings be shown
+     */
+    public static final XSLTProperty HEADINGS = new XSLTProperty("Headings", true); //$NON-NLS-1$
+
     /**
      * Should notes be shown
      */
@@ -157,24 +162,6 @@ public final class XSLTProperty implements Serializable
         return VALUES[i];
     }
 
-    /**
-     * Prevent subclasses from overriding canonical identity based Object methods
-     * @see java.lang.Object#equals(java.lang.Object)
-     */
-    public boolean equals(Object o)
-    {
-        return super.equals(o);
-    }
-
-    /**
-     * Prevent subclasses from overriding canonical identity based Object methods
-     * @see java.lang.Object#hashCode()
-     */
-    public int hashCode()
-    {
-        return super.hashCode();
-    }
-
     /* (non-Javadoc)
      * @see java.lang.Object#toString()
      */
@@ -217,6 +204,7 @@ public final class XSLTProperty implements Serializable
         BCV,
         NO_VERSE_NUMBERS,
         TINY_VERSE_NUMBERS,
+        HEADINGS,
         NOTES,
         XREF,
     };
