@@ -17,10 +17,11 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: BookFilters.java 1095 2006-07-23 19:15:47Z dmsmith $
+ * ID: $Id: BookFilters.java 1264 2007-03-30 18:00:18Z dmsmith $
  */
 package org.crosswire.jsword.book;
 
+import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.List;
@@ -48,47 +49,41 @@ public final class BookFilters
      */
     public static BookFilter getAll()
     {
-        return allBookFilter;
-    }
-
-    /**
-     * Filter for all books
-     */
-    private static BookFilter allBookFilter = new AllBookFilter();
-
-    /**
-     * Filter for all books
-     */
-    static class AllBookFilter implements BookFilter
-    {
-        public boolean test(Book book)
-        {
-            return true;
-        }
+        return new AllBookFilter();
     }
 
     /**
      * A filter that accepts everything that implements Bible
+     * or Commentary, when commentaries are listed with Bibles.
      */
     public static BookFilter getBibles()
     {
-        return biblesBookFilter;
+        if (commentariesWithBibles)
+        {
+            return either(new BookCategoryFilter(BookCategory.BIBLE), new BookCategoryFilter(BookCategory.COMMENTARY));
+        }
+        return new BookCategoryFilter(BookCategory.BIBLE);
     }
 
     /**
-     * Filter for all Bibles
+     * A filter that accepts everything that implements Bible.
      */
-    private static BookFilter biblesBookFilter = new BiblesBookFilter();
+    public static BookFilter getOnlyBibles()
+    {
+        return new BookCategoryFilter(BookCategory.BIBLE);
+    }
 
     /**
-     * Filter for all Bibles
+     * A filter that accepts everything that's not a Bible
+     * or a Commentary, when commentaries are listed with Bibles.
      */
-    static class BiblesBookFilter implements BookFilter
+    public static BookFilter getNonBibles()
     {
-        public boolean test(Book book)
+        if (commentariesWithBibles)
         {
-            return book.getBookCategory().equals(BookCategory.BIBLE) && !book.isLocked();
+            return both(new NotBookCategoryFilter(BookCategory.BIBLE), new NotBookCategoryFilter(BookCategory.COMMENTARY));
         }
+        return new NotBookCategoryFilter(BookCategory.BIBLE);
     }
 
     /**
@@ -96,25 +91,15 @@ public final class BookFilters
      */
     public static BookFilter getDictionaries()
     {
-        return dictionariesBookFilter;
+        return new BookCategoryFilter(BookCategory.DICTIONARY);
     }
 
     /**
-     * Filter for all dictionaries
+     * A filter that accepts everything that implements Dictionary
      */
-    private static BookFilter dictionariesBookFilter = new DictionariesBookFilter();
-
-    /**
-     * Filter for all dictionaries
-     */
-    static class DictionariesBookFilter implements BookFilter
+    public static BookFilter getGlossaries()
     {
-        public boolean test(Book book)
-        {
-            BookCategory category = book.getBookCategory();
-            return (category.equals(BookCategory.DICTIONARY) || category.equals(BookCategory.GLOSSARY))
-                  && !book.isLocked();
-        }
+        return new BookCategoryFilter(BookCategory.GLOSSARY);
     }
 
     /**
@@ -122,24 +107,7 @@ public final class BookFilters
      */
     public static BookFilter getDailyDevotionals()
     {
-        return dailyDevotionalsBookFilter;
-    }
-
-    /**
-     * Filter for all dictionaries
-     */
-    private static BookFilter dailyDevotionalsBookFilter = new DailyDevotionalsBookFilter();
-
-    /**
-     * Filter for all dictionaries
-     */
-    static class DailyDevotionalsBookFilter implements BookFilter
-    {
-        public boolean test(Book book)
-        {
-            BookCategory category = book.getBookCategory();
-            return category.equals(BookCategory.DAILY_DEVOTIONS) && !book.isLocked();
-        }
+        return new BookCategoryFilter(BookCategory.DAILY_DEVOTIONS);
     }
 
     /**
@@ -147,23 +115,15 @@ public final class BookFilters
      */
     public static BookFilter getCommentaries()
     {
-        return commentariesBookFilter;
+        return new BookCategoryFilter(BookCategory.COMMENTARY);
     }
 
     /**
-     * Filter for all commentaries
+     * A filter that accepts everything that implements GeneralBook
      */
-    private static BookFilter commentariesBookFilter = new CommentariesBookFilter();
-
-    /**
-     * Filter for all commentaries
-     */
-    static class CommentariesBookFilter implements BookFilter
+    public static BookFilter getGeneralBooks()
     {
-        public boolean test(Book book)
-        {
-            return book.getBookCategory().equals(BookCategory.COMMENTARY) && !book.isLocked();
-        }
+        return new BookCategoryFilter(BookCategory.GENERAL_BOOK);
     }
 
     /**
@@ -172,23 +132,7 @@ public final class BookFilters
      */
     public static BookFilter getGreekDefinitions()
     {
-        return greekDefinitionsBookFilter;
-    }
-
-    /**
-     * Filter for all Greek Definition Dictionaries
-     */
-    private static BookFilter greekDefinitionsBookFilter = new GreekDefinitionsBookFilter();
-
-    /**
-     * Filter for all Greek Definition Dictionaries
-     */
-    static class GreekDefinitionsBookFilter implements BookFilter
-    {
-        public boolean test(Book book)
-        {
-            return book.hasFeature(FeatureType.GREEK_DEFINITIONS) && !book.isLocked();
-        }
+        return new BookFeatureFilter(FeatureType.GREEK_DEFINITIONS);
     }
 
     /**
@@ -197,23 +141,7 @@ public final class BookFilters
      */
     public static BookFilter getGreekParse()
     {
-        return greekParseBookFilter;
-    }
-
-    /**
-     * Filter for all Greek Parse/Morphology Dictionaries
-     */
-    private static BookFilter greekParseBookFilter = new GreekParseBookFilter();
-
-    /**
-     * Filter for all Greek Parse/Morphology Dictionaries
-     */
-    static class GreekParseBookFilter implements BookFilter
-    {
-        public boolean test(Book book)
-        {
-            return book.hasFeature(FeatureType.GREEK_PARSE) && !book.isLocked();
-        }
+        return new BookFeatureFilter(FeatureType.GREEK_PARSE);
     }
 
     /**
@@ -222,23 +150,7 @@ public final class BookFilters
      */
     public static BookFilter getHebrewDefinitions()
     {
-        return hebrewDefinitionsBookFilter;
-    }
-
-    /**
-     * Filter for all Hebrew Definition Dictionaries
-     */
-    private static BookFilter hebrewDefinitionsBookFilter = new HebrewDefinitionsBookFilter();
-
-    /**
-     * Filter for all Hebrew Definition Dictionaries
-     */
-    static class HebrewDefinitionsBookFilter implements BookFilter
-    {
-        public boolean test(Book book)
-        {
-            return book.hasFeature(FeatureType.HEBREW_DEFINITIONS) && !book.isLocked();
-        }
+        return new BookFeatureFilter(FeatureType.HEBREW_DEFINITIONS);
     }
 
     /**
@@ -247,25 +159,112 @@ public final class BookFilters
      */
     public static BookFilter getHebrewParse()
     {
-        return hebrewParseBookFilter;
+        return new BookFeatureFilter(FeatureType.HEBREW_PARSE);
     }
 
     /**
-     * Filter for all Hebrew Parse/Morphology Dictionaries
+     * Determine whether the getBible should return the current Bible
+     * or the user's chosen default.
+     * @return true if the bible tracks the user's selection
      */
-    private static BookFilter hebrewParseBookFilter = new HebrewParseBookFilter();
+    public static boolean isCommentariesWithBibles()
+    {
+        return commentariesWithBibles;
+    }
 
     /**
-     * Filter for all Hebrew Parse/Morphology Dictionaries
+     * Establish whether the getBible should return the current Bible
+     * or the user's chosen default.
+     * @param current
      */
-    static class HebrewParseBookFilter implements BookFilter
+    public static void setCommentariesWithBibles(boolean current)
     {
+        commentariesWithBibles = current;
+    }
+
+    /**
+     * Whether biblesBookFilter includes commentaries. Initally false.
+     */
+    private static boolean    commentariesWithBibles;
+
+
+    /**
+     * Filter for all books
+     */
+    static class AllBookFilter implements BookFilter
+    {
+        /* (non-Javadoc)
+         * @see org.crosswire.jsword.book.BookFilter#test(org.crosswire.jsword.book.Book)
+         */
         public boolean test(Book book)
         {
-            return book.hasFeature(FeatureType.HEBREW_PARSE) && !book.isLocked();
+            return true;
         }
     }
 
+    /**
+     * Filter for books by category
+     */
+    static class BookCategoryFilter implements BookFilter
+    {
+        BookCategoryFilter(BookCategory category)
+        {
+            this.category = category;
+        }
+
+        /* (non-Javadoc)
+         * @see org.crosswire.jsword.book.BookFilter#test(org.crosswire.jsword.book.Book)
+         */
+        public boolean test(Book book)
+        {
+            return book.getBookCategory().equals(category) && !book.isLocked();
+        }
+
+        private BookCategory category;
+    }
+
+    /**
+     * Filter for books by category
+     */
+    static class NotBookCategoryFilter implements BookFilter
+    {
+        NotBookCategoryFilter(BookCategory category)
+        {
+            this.category = category;
+        }
+
+        /* (non-Javadoc)
+         * @see org.crosswire.jsword.book.BookFilter#test(org.crosswire.jsword.book.Book)
+         */
+        public boolean test(Book book)
+        {
+            return !book.getBookCategory().equals(category) && !book.isLocked();
+        }
+
+        private BookCategory category;
+    }
+
+    /**
+     * Filter for books by feature
+     */
+    static class BookFeatureFilter implements BookFilter
+    {
+        BookFeatureFilter(FeatureType feature)
+        {
+            this.feature = feature;
+        }
+
+        /* (non-Javadoc)
+         * @see org.crosswire.jsword.book.BookFilter#test(org.crosswire.jsword.book.Book)
+         */
+        public boolean test(Book book)
+        {
+            return book.hasFeature(feature) && !book.isLocked();
+        }
+
+        private FeatureType feature;
+    }
+
     /**
      * A filter that accepts Books that match two criteria.
      */
@@ -295,7 +294,7 @@ public final class BookFilters
     }
 
     /**
-     * A filter that accepts Books that match either of two criteria.
+     * A filter that accepts Books that match by book driver.
      */
     public static BookFilter getBooksByDriver(final BookDriver driver)
     {
@@ -353,7 +352,7 @@ public final class BookFilters
                     test.property = Book.class.getMethod(gettername, (Class[]) null);
                     test.result = parts[1];
                 }
-                catch (Exception ex)
+                catch (NoSuchMethodException ex)
                 {
                     throw new IllegalArgumentException("Missing property: " + parts[0] + " in Book"); //$NON-NLS-1$ //$NON-NLS-2$
                 }
@@ -380,9 +379,19 @@ public final class BookFilters
                         return false;
                     }
                 }
-                catch (Exception ex)
+                catch (IllegalArgumentException e)
                 {
-                    log.warn("Error while testing property " + test.property.getName() + " on " + book.getName(), ex); //$NON-NLS-1$ //$NON-NLS-2$
+                    log.warn("Error while testing property " + test.property.getName() + " on " + book.getName(), e); //$NON-NLS-1$ //$NON-NLS-2$
+                    return false;
+                }
+                catch (IllegalAccessException e)
+                {
+                    log.warn("Error while testing property " + test.property.getName() + " on " + book.getName(), e); //$NON-NLS-1$ //$NON-NLS-2$
+                    return false;
+                }
+                catch (InvocationTargetException e)
+                {
+                    log.warn("Error while testing property " + test.property.getName() + " on " + book.getName(), e); //$NON-NLS-1$ //$NON-NLS-2$
                     return false;
                 }
             }
@@ -395,7 +404,7 @@ public final class BookFilters
         /**
          *
          */
-        class Test
+        static class Test
         {
             protected String result;
             protected Method property;
@@ -405,5 +414,5 @@ public final class BookFilters
     /**
      * The log stream
      */
-    protected static final Logger log = Logger.getLogger(BookFilters.class);
+    static final Logger log = Logger.getLogger(BookFilters.class);
 }
