@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: GBFTags.java 1068 2006-04-08 02:20:41Z dmsmith $
+ * ID: $Id: GBFTags.java 1152 2006-10-10 23:30:55Z dmsmith $
  */
 package org.crosswire.jsword.book.filter.gbf;
 
@@ -603,7 +603,7 @@ public final class GBFTags
                 newLemma.append(existingLemma).append('|');
             }
 
-            newLemma.append(OSISUtil.LEMMA_STRONGS).append(name.substring(2)); //$NON-NLS-1$
+            newLemma.append(OSISUtil.LEMMA_STRONGS).append(name.substring(2));
             word.setAttribute(OSISUtil.ATTRIBUTE_W_LEMMA, newLemma.toString());
         }
     }
@@ -721,10 +721,10 @@ public final class GBFTags
     /**
      * To convert strings into Biblical keys.
      */
-    protected static final KeyFactory KEY_FACTORY = PassageKeyFactory.instance();
+    static final KeyFactory KEY_FACTORY = PassageKeyFactory.instance();
 
     /**
      * To create OSIS DOM nodes.
      */
-    protected static final OSISFactory OSIS_FACTORY = OSISUtil.factory();
+    static final OSISFactory OSIS_FACTORY = OSISUtil.factory();
 }
