@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: AbstractPassage.java 1068 2006-04-08 02:20:41Z dmsmith $
+ * ID: $Id: AbstractPassage.java 1221 2006-12-19 22:50:05Z dmsmith $
  */
 package org.crosswire.jsword.passage;
 
@@ -36,6 +36,7 @@ import java.util.NoSuchElementException;
 
 import org.crosswire.common.util.Logger;
 import org.crosswire.common.util.StringUtil;
+import org.crosswire.jsword.versification.BibleInfo;
 
 /**
  * This is a base class to help with some of the common implementation
@@ -54,15 +55,17 @@ public abstract class AbstractPassage implements Passage
      */
     protected AbstractPassage()
     {
+        this(null);
     }
 
     /**
      * Setup the original name of this reference
-     * @param original_name The text originally used to create this Passage.
+     * @param passageName The text originally used to create this Passage.
      */
-    protected AbstractPassage(String original_name)
+    protected AbstractPassage(String passageName)
     {
-        this.originalName = original_name;
+        originalName = passageName;
+        listeners = new ArrayList();
     }
 
     /* (non-Javadoc)
@@ -111,17 +114,16 @@ public abstract class AbstractPassage implements Passage
         try
         {
             copy = (AbstractPassage) super.clone();
+            copy.listeners = new ArrayList();
+            copy.listeners.addAll(listeners);
+
+            copy.originalName  = originalName;
         }
         catch (CloneNotSupportedException e)
         {
             assert false : e;
         }
 
-        copy.listeners = new ArrayList();
-        copy.listeners.addAll(listeners);
-
-        copy.originalName  = originalName;
-
         return copy;
     }
 
@@ -204,6 +206,18 @@ public abstract class AbstractPassage implements Passage
         return getName();
     }
 
+    public String getRootName()
+    {
+        Iterator it = rangeIterator(RestrictionType.NONE);
+        while (it.hasNext())
+        {
+            VerseRange range = (VerseRange) it.next();
+            return range.getRootName();
+        }
+
+        return getName();
+    }
+
     /* (non-Javadoc)
      * @see org.crosswire.jsword.passage.Passage#getOSISName()
      */
@@ -793,9 +807,9 @@ public abstract class AbstractPassage implements Passage
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.passage.Key#size()
+     * @see org.crosswire.jsword.passage.Key#getCardinality()
      */
-    public int getChildCount()
+    public int getCardinality()
     {
         return countVerses();
     }
@@ -823,13 +837,21 @@ public abstract class AbstractPassage implements Passage
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.passage.Key#isLeaf()
+     * @see org.crosswire.jsword.passage.Key#canHaveChildren()
      */
     public boolean canHaveChildren()
     {
         return false;
     }
 
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getChildCount()
+     */
+    public int getChildCount()
+    {
+        return 0;
+    }
+
     /* (non-Javadoc)
      * @see org.crosswire.jsword.passage.Key#get(int)
      */
@@ -1002,7 +1024,7 @@ public abstract class AbstractPassage implements Passage
      * synchronised, however this is safe, and I don't think there is
      * a cost associated with a double synchronize. (?)
      */
-    protected void normalize()
+    /*protected*/ void normalize()
     {
         // before doing any normalization we should be checking that
         // skip_normalization == 0, and just returning if so.
@@ -1024,7 +1046,7 @@ public abstract class AbstractPassage implements Passage
             // chance to fix the error
             //   throw new LogicError();
 
-            log.warn("skip_normalization=" + skipNormalization, new Exception()); //$NON-NLS-1$
+            log.warn("skip_normalization=" + skipNormalization); //$NON-NLS-1$
         }
     }
 
@@ -1062,7 +1084,7 @@ public abstract class AbstractPassage implements Passage
             // chance to fix the error
             //   throw new LogicError();
 
-            log.warn("suppress_events=" + suppressEvents, new Exception()); //$NON-NLS-1$
+            log.warn("suppress_events=" + suppressEvents); //$NON-NLS-1$
         }
     }
 
@@ -1242,10 +1264,6 @@ public abstract class AbstractPassage implements Passage
      */
     protected void writeObjectSupport(ObjectOutputStream out) throws IOException
     {
-        // This allows our children to have default serializable fields
-        // even though we have none.
-        out.defaultWriteObject();
-
         // the size in bits of teach storage method
         int bitwise_size = BibleInfo.versesInBible();
         int ranged_size =  8 * countRanges(RestrictionType.NONE);
@@ -1294,7 +1312,7 @@ public abstract class AbstractPassage implements Passage
             {
                 VerseRange range = (VerseRange) it.next();
                 out.writeInt(range.getStart().getOrdinal());
-                out.writeInt(range.getVerseCount());
+                out.writeInt(range.getCardinality());
             }
         }
 
@@ -1303,31 +1321,42 @@ public abstract class AbstractPassage implements Passage
         // it could make everything far more verbose
     }
 
+    /**
+     * Serialization support.
+     * 
+     * @param is
+     * @throws IOException
+     * @throws ClassNotFoundException
+     */
+    private void readObject(ObjectInputStream is) throws IOException, ClassNotFoundException
+    {
+        listeners = new ArrayList();
+        originalName = null;
+        parent = null;
+        skipNormalization = 0;
+        suppressEvents = 0;
+
+        is.defaultReadObject();
+    }
+
     /**
      * Write out the object to the given ObjectOutputStream
-     * @param in The stream to read our state from
+     * @param is The stream to read our state from
      * @throws IOException if the read fails
      * @throws ClassNotFoundException If the read data is incorrect
      */
-    protected void readObjectSupport(ObjectInputStream in) throws IOException, ClassNotFoundException
+    protected void readObjectSupport(ObjectInputStream is) throws IOException, ClassNotFoundException
     {
         raiseEventSuppresion();
         raiseNormalizeProtection();
 
-        // This allows our children to have default serializable fields
-        // even though we have none.
-        in.defaultReadObject();
-
-        // Setup
-        listeners = new ArrayList();
-
         try
         {
-            int type = in.readInt();
+            int type = is.readInt();
             switch (type)
             {
             case BITWISE:
-                BitSet store = (BitSet) in.readObject();
+                BitSet store = (BitSet) is.readObject();
                 for (int i = 0; i < BibleInfo.versesInBible(); i++)
                 {
                     if (store.get(i))
@@ -1338,20 +1367,20 @@ public abstract class AbstractPassage implements Passage
                 break;
 
             case DISTINCT:
-                int verses = in.readInt();
+                int verses = is.readInt();
                 for (int i = 0; i < verses; i++)
                 {
-                    int ord = in.readInt();
+                    int ord = is.readInt();
                     add(new Verse(ord));
                 }
                 break;
 
             case RANGED:
-                int ranges = in.readInt();
+                int ranges = is.readInt();
                 for (int i = 0; i < ranges; i++)
                 {
-                    int ord = in.readInt();
-                    int count = in.readInt();
+                    int ord = is.readInt();
+                    int count = is.readInt();
                     add(RestrictionType.NONE.toRange(new Verse(ord), count));
                 }
                 break;
@@ -1409,7 +1438,7 @@ public abstract class AbstractPassage implements Passage
     /**
      * Support for change notification
      */
-    protected transient List listeners = new ArrayList();
+    protected transient List listeners;
 
     /**
      * The original string for picky users
