@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: AccuracyType.java 1177 2006-11-05 20:28:23Z dmsmith $
+ * ID: $Id: AccuracyType.java 1248 2007-02-13 18:26:11Z dmsmith $
  */
 package org.crosswire.jsword.passage;
 
@@ -662,7 +662,7 @@ public abstract class AccuracyType implements Serializable
         for (int i = 0; i < length; i++)
         {
             curChar = input.charAt(i);
-            boolean charIsDigit = curChar == '$' || Character.isDigit(curChar) || (curChar == 'f' && (i + 1 < length ? input.charAt(i + 1) : ' ') == 'f');
+            boolean charIsDigit = curChar == '$' || Character.isDigit(curChar) || (curChar == 'f' && (i + 1 < length ? input.charAt(i + 1) : ' ') == 'f' && !Character.isLetter(lastChar));
             if (charIsDigit || Character.isLetter(curChar))
             {
                 foundBoundary = true;
