@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: VerseRange.java 1178 2006-11-06 12:48:02Z dmsmith $
+ * ID: $Id: VerseRange.java 1221 2006-12-19 22:50:05Z dmsmith $
  */
 package org.crosswire.jsword.passage;
 
@@ -127,19 +127,16 @@ public final class VerseRange implements Key, Serializable
         verseCount = calcVerseCount(start, end);
     }
 
-    /**
-     * Fetch a more sensible shortened version of the name
-     * @return A string like 'Gen 1:1-2'
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getName()
      */
     public String getName()
     {
         return getName(null);
     }
 
-    /**
-     * Fetch a more sensible shortened version of the name
-     * @param base A reference to allow things like Gen 1:1,3,5 as an output
-     * @return A string like 'Gen 1:1-2'
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getName(org.crosswire.jsword.passage.Key)
      */
     public String getName(Key base)
     {
@@ -236,10 +233,16 @@ public final class VerseRange implements Key, Serializable
         }
     }
 
-    /**
-     * The OSIS defined reference specification for this VerseRange.
-     * Uses osis books names, with "." as a verse part separator.
-     * @return a String containing the OSIS description of the verses
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getRootName()
+     */
+    public String getRootName()
+    {
+        return start.getRootName();
+    }
+
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getOsisRef()
      */
     public String getOsisRef()
     {
@@ -293,11 +296,8 @@ public final class VerseRange implements Key, Serializable
         }
     }
 
-    /**
-     * The OSIS defined id specification for this VerseRange.
-     * Uses osis books names, with "." as a verse part separator.
-     * Each verse is separated by a space.
-     * @return a String containing the OSIS description of the verses
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getOsisID()
      */
     public String getOsisID()
     {
@@ -357,10 +357,8 @@ public final class VerseRange implements Key, Serializable
         return buf.toString();
     }
 
-    /**
-     * This just clones getName which seems the most sensible
-     * type of string to return.
-     * @return A string like 'Gen 1:1-2'
+    /* (non-Javadoc)
+     * @see java.lang.Object#toString()
      */
     public String toString()
     {
@@ -385,15 +383,6 @@ public final class VerseRange implements Key, Serializable
         return end;
     }
 
-    /**
-     * How many verses in this range
-     * @return The number of verses. Always >= 1.
-     */
-    public int getVerseCount()
-    {
-        return verseCount;
-    }
-
     /**
      * How many chapters in this range
      * @return The number of chapters. Always >= 1.
@@ -490,7 +479,7 @@ public final class VerseRange implements Key, Serializable
             return false;
         }
 
-        if (vr.getVerseCount() != getVerseCount())
+        if (vr.getCardinality() != getCardinality())
         {
             return false;
         }
@@ -536,15 +525,15 @@ public final class VerseRange implements Key, Serializable
         int that_length = 1;
         if (obj instanceof VerseRange)
         {
-            that_length = ((VerseRange) obj).getVerseCount();
+            that_length = ((VerseRange) obj).getCardinality();
         }
 
-        if (that_length == getVerseCount())
+        if (that_length == getCardinality())
         {
             return 0;
         }
 
-        if (that_length < getVerseCount())
+        if (that_length < getCardinality())
         {
             return 1;
         }
@@ -1035,13 +1024,21 @@ public final class VerseRange implements Key, Serializable
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.passage.Key#size()
+     * @see org.crosswire.jsword.passage.Key#getChildCount()
      */
     public int getChildCount()
     {
         return 0;
     }
 
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getCardinality()
+     */
+    public int getCardinality()
+    {
+        return verseCount;
+    }
+
     /* (non-Javadoc)
      * @see org.crosswire.jsword.passage.Key#isEmpty()
      */
